==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/WorkspaceNamedValue.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin

import com.pulumi.azurenative.apimanagement.kotlin.outputs.KeyVaultContractPropertiesResponse
import com.pulumi.azurenative.apimanagement.kotlin.outputs.KeyVaultContractPropertiesResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [WorkspaceNamedValue].
 */
@PulumiTagMarker
public class WorkspaceNamedValueResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WorkspaceNamedValueArgs = WorkspaceNamedValueArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WorkspaceNamedValueArgsBuilder.() -> Unit) {
        val builder = WorkspaceNamedValueArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WorkspaceNamedValue {
        val builtJavaResource =
            com.pulumi.azurenative.apimanagement.WorkspaceNamedValue(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WorkspaceNamedValue(builtJavaResource)
    }
}

/**
 * NamedValue details.
 * Azure REST API version: 2022-09-01-preview.
 * Other available API versions: 2023-03-01-preview.
 * ## Example Usage
 * ### ApiManagementCreateWorkspaceNamedValue
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var workspaceNamedValue = new AzureNative.ApiManagement.WorkspaceNamedValue("workspaceNamedValue", new()
 *     {
 *         DisplayName = "prop3name",
 *         NamedValueId = "testprop2",
 *         ResourceGroupName = "rg1",
 *         Secret = false,
 *         ServiceName = "apimService1",
 *         Tags = new[]
 *         {
 *             "foo",
 *             "bar",
 *         },
 *         Value = "propValue",
 *         WorkspaceId = "wks1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apimanagement/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apimanagement.NewWorkspaceNamedValue(ctx, "workspaceNamedValue", &apimanagement.WorkspaceNamedValueArgs{
 * 			DisplayName:       pulumi.String("prop3name"),
 * 			NamedValueId:      pulumi.String("testprop2"),
 * 			ResourceGroupName: pulumi.String("rg1"),
 * 			Secret:            pulumi.Bool(false),
 * 			ServiceName:       pulumi.String("apimService1"),
 * 			Tags: pulumi.StringArray{
 * 				pulumi.String("foo"),
 * 				pulumi.String("bar"),
 * 			},
 * 			Value:       pulumi.String("propValue"),
 * 			WorkspaceId: pulumi.String("wks1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apimanagement.WorkspaceNamedValue;
 * import com.pulumi.azurenative.apimanagement.WorkspaceNamedValueArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var workspaceNamedValue = new WorkspaceNamedValue("workspaceNamedValue", WorkspaceNamedValueArgs.builder()
 *             .displayName("prop3name")
 *             .namedValueId("testprop2")
 *             .resourceGroupName("rg1")
 *             .secret(false)
 *             .serviceName("apimService1")
 *             .tags(
 *                 "foo",
 *                 "bar")
 *             .value("propValue")
 *             .workspaceId("wks1")
 *             .build());
 *     }
 * }
 * ```
 * ### ApiManagementCreateWorkspaceNamedValueWithKeyVault
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var workspaceNamedValue = new AzureNative.ApiManagement.WorkspaceNamedValue("workspaceNamedValue", new()
 *     {
 *         DisplayName = "prop6namekv",
 *         KeyVault = new AzureNative.ApiManagement.Inputs.KeyVaultContractCreatePropertiesArgs
 *         {
 *             IdentityClientId = "ceaa6b06-c00f-43ef-99ac-f53d1fe876a0",
 *             SecretIdentifier = "https://contoso.vault.azure.net/secrets/aadSecret",
 *         },
 *         NamedValueId = "testprop6",
 *         ResourceGroupName = "rg1",
 *         Secret = true,
 *         ServiceName = "apimService1",
 *         Tags = new[]
 *         {
 *             "foo",
 *             "bar",
 *         },
 *         WorkspaceId = "wks1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apimanagement/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apimanagement.NewWorkspaceNamedValue(ctx, "workspaceNamedValue", &apimanagement.WorkspaceNamedValueArgs{
 * 			DisplayName: pulumi.String("prop6namekv"),
 * 			KeyVault: &apimanagement.KeyVaultContractCreatePropertiesArgs{
 * 				IdentityClientId: pulumi.String("ceaa6b06-c00f-43ef-99ac-f53d1fe876a0"),
 * 				SecretIdentifier: pulumi.String("https://contoso.vault.azure.net/secrets/aadSecret"),
 * 			},
 * 			NamedValueId:      pulumi.String("testprop6"),
 * 			ResourceGroupName: pulumi.String("rg1"),
 * 			Secret:            pulumi.Bool(true),
 * 			ServiceName:       pulumi.String("apimService1"),
 * 			Tags: pulumi.StringArray{
 * 				pulumi.String("foo"),
 * 				pulumi.String("bar"),
 * 			},
 * 			WorkspaceId: pulumi.String("wks1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apimanagement.WorkspaceNamedValue;
 * import com.pulumi.azurenative.apimanagement.WorkspaceNamedValueArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var workspaceNamedValue = new WorkspaceNamedValue("workspaceNamedValue", WorkspaceNamedValueArgs.builder()
 *             .displayName("prop6namekv")
 *             .keyVault(Map.ofEntries(
 *                 Map.entry("identityClientId", "ceaa6b06-c00f-43ef-99ac-f53d1fe876a0"),
 *                 Map.entry("secretIdentifier", "https://contoso.vault.azure.net/secrets/aadSecret")
 *             ))
 *             .namedValueId("testprop6")
 *             .resourceGroupName("rg1")
 *             .secret(true)
 *             .serviceName("apimService1")
 *             .tags(
 *                 "foo",
 *                 "bar")
 *             .workspaceId("wks1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:apimanagement:WorkspaceNamedValue testprop6 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ApiManagement/service/{serviceName}/workspaces/{workspaceId}/namedValues/{namedValueId}
 * ```
 */
public class WorkspaceNamedValue internal constructor(
    override val javaResource: com.pulumi.azurenative.apimanagement.WorkspaceNamedValue,
) : KotlinCustomResource(javaResource, WorkspaceNamedValueMapper) {
    /**
     * Unique name of NamedValue. It may contain only letters, digits, period, dash, and underscore characters.
     */
    public val displayName: Output<String>
        get() = javaResource.displayName().applyValue({ args0 -> args0 })

    /**
     * KeyVault location details of the namedValue.
     */
    public val keyVault: Output<KeyVaultContractPropertiesResponse>?
        get() = javaResource.keyVault().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    toKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Determines whether the value is a secret and should be encrypted or not. Default value is false.
     */
    public val secret: Output<Boolean>?
        get() = javaResource.secret().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Optional tags that when provided can be used to filter the NamedValue list.
     */
    public val tags: Output<List<String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0
                })
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })

    /**
     * Value of the NamedValue. Can contain policy expressions. It may not be empty or consist only of whitespace. This property will not be filled on 'GET' operations! Use '/listSecrets' POST request to get the value.
     */
    public val `value`: Output<String>?
        get() = javaResource.`value`().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })
}

public object WorkspaceNamedValueMapper : ResourceMapper<WorkspaceNamedValue> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.apimanagement.WorkspaceNamedValue::class == javaResource::class

    override fun map(javaResource: Resource): WorkspaceNamedValue = WorkspaceNamedValue(
        javaResource
            as com.pulumi.azurenative.apimanagement.WorkspaceNamedValue,
    )
}

/**
 * @see [WorkspaceNamedValue].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WorkspaceNamedValue].
 */
public suspend fun workspaceNamedValue(
    name: String,
    block: suspend WorkspaceNamedValueResourceBuilder.() -> Unit,
): WorkspaceNamedValue {
    val builder = WorkspaceNamedValueResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WorkspaceNamedValue].
 * @param name The _unique_ name of the resulting resource.
 */
public fun workspaceNamedValue(name: String): WorkspaceNamedValue {
    val builder = WorkspaceNamedValueResourceBuilder()
    builder.name(name)
    return builder.build()
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/apimanagement/kotlin/WorkspaceNamedValue.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.apimanagement.kotlin

import com.pulumi.azurenative.apimanagement.kotlin.outputs.KeyVaultContractPropertiesResponse
import com.pulumi.azurenative.apimanagement.kotlin.outputs.KeyVaultContractPropertiesResponse.Companion.toKotlin
import com.pulumi.core.Output
import com.pulumi.kotlin.KotlinCustomResource
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.ResourceMapper
import com.pulumi.kotlin.options.CustomResourceOptions
import com.pulumi.kotlin.options.CustomResourceOptionsBuilder
import com.pulumi.resources.Resource
import kotlin.Boolean
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List

/**
 * Builder for [WorkspaceNamedValue].
 */
@PulumiTagMarker
public class WorkspaceNamedValueResourceBuilder internal constructor() {
    public var name: String? = null

    public var args: WorkspaceNamedValueArgs = WorkspaceNamedValueArgs()

    public var opts: CustomResourceOptions = CustomResourceOptions()

    /**
     * @param name The _unique_ name of the resulting resource.
     */
    public fun name(`value`: String) {
        this.name = value
    }

    /**
     * @param block The arguments to use to populate this resource's properties.
     */
    public suspend fun args(block: suspend WorkspaceNamedValueArgsBuilder.() -> Unit) {
        val builder = WorkspaceNamedValueArgsBuilder()
        block(builder)
        this.args = builder.build()
    }

    /**
     * @param block A bag of options that control this resource's behavior.
     */
    public suspend fun opts(block: suspend CustomResourceOptionsBuilder.() -> Unit) {
        this.opts = com.pulumi.kotlin.options.opts(block)
    }

    internal fun build(): WorkspaceNamedValue {
        val builtJavaResource =
            com.pulumi.azurenative.apimanagement.WorkspaceNamedValue(
                this.name,
                this.args.toJava(),
                this.opts.toJava(),
            )
        return WorkspaceNamedValue(builtJavaResource)
    }
}

/**
 * NamedValue details.
 * Azure REST API version: 2022-09-01-preview.
 * Other available API versions: 2023-03-01-preview, 2023-05-01-preview.
 * ## Example Usage
 * ### ApiManagementCreateWorkspaceNamedValue
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var workspaceNamedValue = new AzureNative.ApiManagement.WorkspaceNamedValue("workspaceNamedValue", new()
 *     {
 *         DisplayName = "prop3name",
 *         NamedValueId = "testprop2",
 *         ResourceGroupName = "rg1",
 *         Secret = false,
 *         ServiceName = "apimService1",
 *         Tags = new[]
 *         {
 *             "foo",
 *             "bar",
 *         },
 *         Value = "propValue",
 *         WorkspaceId = "wks1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apimanagement/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apimanagement.NewWorkspaceNamedValue(ctx, "workspaceNamedValue", &apimanagement.WorkspaceNamedValueArgs{
 * 			DisplayName:       pulumi.String("prop3name"),
 * 			NamedValueId:      pulumi.String("testprop2"),
 * 			ResourceGroupName: pulumi.String("rg1"),
 * 			Secret:            pulumi.Bool(false),
 * 			ServiceName:       pulumi.String("apimService1"),
 * 			Tags: pulumi.StringArray{
 * 				pulumi.String("foo"),
 * 				pulumi.String("bar"),
 * 			},
 * 			Value:       pulumi.String("propValue"),
 * 			WorkspaceId: pulumi.String("wks1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apimanagement.WorkspaceNamedValue;
 * import com.pulumi.azurenative.apimanagement.WorkspaceNamedValueArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var workspaceNamedValue = new WorkspaceNamedValue("workspaceNamedValue", WorkspaceNamedValueArgs.builder()
 *             .displayName("prop3name")
 *             .namedValueId("testprop2")
 *             .resourceGroupName("rg1")
 *             .secret(false)
 *             .serviceName("apimService1")
 *             .tags(
 *                 "foo",
 *                 "bar")
 *             .value("propValue")
 *             .workspaceId("wks1")
 *             .build());
 *     }
 * }
 * ```
 * ### ApiManagementCreateWorkspaceNamedValueWithKeyVault
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var workspaceNamedValue = new AzureNative.ApiManagement.WorkspaceNamedValue("workspaceNamedValue", new()
 *     {
 *         DisplayName = "prop6namekv",
 *         KeyVault = new AzureNative.ApiManagement.Inputs.KeyVaultContractCreatePropertiesArgs
 *         {
 *             IdentityClientId = "ceaa6b06-c00f-43ef-99ac-f53d1fe876a0",
 *             SecretIdentifier = "https://contoso.vault.azure.net/secrets/aadSecret",
 *         },
 *         NamedValueId = "testprop6",
 *         ResourceGroupName = "rg1",
 *         Secret = true,
 *         ServiceName = "apimService1",
 *         Tags = new[]
 *         {
 *             "foo",
 *             "bar",
 *         },
 *         WorkspaceId = "wks1",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/apimanagement/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := apimanagement.NewWorkspaceNamedValue(ctx, "workspaceNamedValue", &apimanagement.WorkspaceNamedValueArgs{
 * 			DisplayName: pulumi.String("prop6namekv"),
 * 			KeyVault: &apimanagement.KeyVaultContractCreatePropertiesArgs{
 * 				IdentityClientId: pulumi.String("ceaa6b06-c00f-43ef-99ac-f53d1fe876a0"),
 * 				SecretIdentifier: pulumi.String("https://contoso.vault.azure.net/secrets/aadSecret"),
 * 			},
 * 			NamedValueId:      pulumi.String("testprop6"),
 * 			ResourceGroupName: pulumi.String("rg1"),
 * 			Secret:            pulumi.Bool(true),
 * 			ServiceName:       pulumi.String("apimService1"),
 * 			Tags: pulumi.StringArray{
 * 				pulumi.String("foo"),
 * 				pulumi.String("bar"),
 * 			},
 * 			WorkspaceId: pulumi.String("wks1"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.apimanagement.WorkspaceNamedValue;
 * import com.pulumi.azurenative.apimanagement.WorkspaceNamedValueArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var workspaceNamedValue = new WorkspaceNamedValue("workspaceNamedValue", WorkspaceNamedValueArgs.builder()
 *             .displayName("prop6namekv")
 *             .keyVault(Map.ofEntries(
 *                 Map.entry("identityClientId", "ceaa6b06-c00f-43ef-99ac-f53d1fe876a0"),
 *                 Map.entry("secretIdentifier", "https://contoso.vault.azure.net/secrets/aadSecret")
 *             ))
 *             .namedValueId("testprop6")
 *             .resourceGroupName("rg1")
 *             .secret(true)
 *             .serviceName("apimService1")
 *             .tags(
 *                 "foo",
 *                 "bar")
 *             .workspaceId("wks1")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:apimanagement:WorkspaceNamedValue testprop6 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.ApiManagement/service/{serviceName}/workspaces/{workspaceId}/namedValues/{namedValueId}
 * ```
 */
public class WorkspaceNamedValue internal constructor(
    override val javaResource: com.pulumi.azurenative.apimanagement.WorkspaceNamedValue,
) : KotlinCustomResource(javaResource, WorkspaceNamedValueMapper) {
    /**
     * Unique name of NamedValue. It may contain only letters, digits, period, dash, and underscore characters.
     */
    public val displayName: Output<String>
        get() = javaResource.displayName().applyValue({ args0 -> args0 })

    /**
     * KeyVault location details of the namedValue.
     */
    public val keyVault: Output<KeyVaultContractPropertiesResponse>?
        get() = javaResource.keyVault().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.let({ args0 ->
                    toKotlin(args0)
                })
            }).orElse(null)
        })

    /**
     * The name of the resource
     */
    public val name: Output<String>
        get() = javaResource.name().applyValue({ args0 -> args0 })

    /**
     * Determines whether the value is a secret and should be encrypted or not. Default value is false.
     */
    public val secret: Output<Boolean>?
        get() = javaResource.secret().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })

    /**
     * Optional tags that when provided can be used to filter the NamedValue list.
     */
    public val tags: Output<List<String>>?
        get() = javaResource.tags().applyValue({ args0 ->
            args0.map({ args0 ->
                args0.map({ args0 ->
                    args0
                })
            }).orElse(null)
        })

    /**
     * The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
     */
    public val type: Output<String>
        get() = javaResource.type().applyValue({ args0 -> args0 })

    /**
     * Value of the NamedValue. Can contain policy expressions. It may not be empty or consist only of whitespace. This property will not be filled on 'GET' operations! Use '/listSecrets' POST request to get the value.
     */
    public val `value`: Output<String>?
        get() = javaResource.`value`().applyValue({ args0 -> args0.map({ args0 -> args0 }).orElse(null) })
}

public object WorkspaceNamedValueMapper : ResourceMapper<WorkspaceNamedValue> {
    override fun supportsMappingOfType(javaResource: Resource): Boolean =
        com.pulumi.azurenative.apimanagement.WorkspaceNamedValue::class == javaResource::class

    override fun map(javaResource: Resource): WorkspaceNamedValue = WorkspaceNamedValue(
        javaResource
            as com.pulumi.azurenative.apimanagement.WorkspaceNamedValue,
    )
}

/**
 * @see [WorkspaceNamedValue].
 * @param name The _unique_ name of the resulting resource.
 * @param block Builder for [WorkspaceNamedValue].
 */
public suspend fun workspaceNamedValue(
    name: String,
    block: suspend WorkspaceNamedValueResourceBuilder.() -> Unit,
): WorkspaceNamedValue {
    val builder = WorkspaceNamedValueResourceBuilder()
    builder.name(name)
    block(builder)
    return builder.build()
}

/**
 * @see [WorkspaceNamedValue].
 * @param name The _unique_ name of the resulting resource.
 */
public fun workspaceNamedValue(name: String): WorkspaceNamedValue {
    val builder = WorkspaceNamedValueResourceBuilder()
    builder.name(name)
    return builder.build()
}
